@@ -13,7 +13,7 @@ gchar *s = N_("Set defaults");
 gchar *s = N_("Assistant");
 gchar *s = N_("Mount");
 gchar *s = N_("Remove");
-gchar *s = N_("Information");
+gchar *s = N_("<b>Information</b>");
 gchar *s = N_("General Configuration");
 gchar *s = N_("name");
 gchar *s = N_("vendor");
@@ -25,11 +25,11 @@ gchar *s = N_("Model");
 gchar *s = N_("Serial");
 gchar *s = N_("Bus");
 gchar *s = N_("bus");
-gchar *s = N_("Attributes");
+gchar *s = N_("<b>Attributes</b>");
 gchar *s = N_("Up");
 gchar *s = N_("Down");
 gchar *s = N_("Edit");
 gchar *s = N_("Delete");
 gchar *s = N_("New");
-gchar *s = N_("Rules");
+gchar *s = N_("<b>Rules</b>");
 gchar *s = N_("Dynamic configuration rules");
