@@ -20,8 +20,8 @@ def is_mountable(device):
 	Uses blkid to check if the given partition is mountable
 		device: the partition to check
 	"""
-	#os.system(BLKID_BIN + " -c /dev/null >> /dev/null")
-	return os.system(BLKID_BIN + " -c /dev/null | grep " + device + " >> /dev/null")==0
+	os.system(BLKID_BIN + " -c /dev/null >> /dev/null")
+	return os.system(BLKID_BIN + " | grep " + device + " >> /dev/null")==0
 
 
 def get_vfstype(device):
@@ -30,7 +30,7 @@ def get_vfstype(device):
 		device: the device
 	"""
 
-	#os.system(BLKID_BIN + " -c /dev/null >> /dev/null")
+	os.system(BLKID_BIN + " -c /dev/null >> /dev/null")
 	#cache = file("/etc/blkid.tab")
 	cache = os.popen(BLKID_BIN + " -c /dev/null " + device)
 	filesystem = cache.readline()
